[![PyPI version](https://badge.fury.io/py/frgeostat.svg)](https://badge.fury.io/py/frgeostat)

# A package to create LeafletJS maps of France

To install, create a virtualenv using whichever method you want, and either:

```shell
pip install frgeostat
```

Or, if you're using [poetry](https://python-poetry.org/), just do:

```shell
# uncomment the line below to trigger venv
# poetry shell
poetry add frgeostat
```

Here's an example of a [map generated by this small module](https://storage.googleapis.com/public.data.v.olt.sh/maps/html/departements.score.volt.map.html).

To get it, just run

```shell
frgeo build -k dept -o departements.score.volt.map.html
```

And wait a dozen seconds, you should see progress bars in the meantime..

# Multiple plots

You can plot several maps at once by repeating the arguments:

```shell
frgeo build -k dept -o dept.map.html -k commune -o co.map.html
```

This will build the `dept` map first and then the `commune` one.
